--- openflow-2014-06-13.h	2015-07-23 09:54:17.636479382 -0700
+++ openflow-2014-01-03.h	2015-07-23 09:54:17.640479382 -0700
@@ -1996,12 +1996,12 @@
     OFPMP_QUEUE_STATS = 5,
 
     /* Group counter statistics.
      * The request body is struct ofp_group_stats_request.
      * The reply is an array of struct ofp_group_stats. */
     OFPMP_GROUP = 6,
 
     /* Group description.
-     * The request body is empty.
+     * The request body is struct ofp_group_multipart_request.
      * The reply body is an array of struct ofp_group_desc. */
     OFPMP_GROUP_DESC = 7,
 
@@ -2455,12 +2455,12 @@
 };
 OFP_ASSERT(sizeof(struct ofp_port_stats) == 80);
 
-/* Body of OFPMP_GROUP request. */
-struct ofp_group_stats_request {
+/* Body of OFPMP_GROUP and OFPMP_GROUP_DESC requests. */
+struct ofp_group_multipart_request {
     uint32_t group_id;       /* All groups if OFPG_ALL. */
     uint8_t pad[4];          /* Align to 64 bits. */
 };
-OFP_ASSERT(sizeof(struct ofp_group_stats_request) == 8);
+OFP_ASSERT(sizeof(struct ofp_group_multipart_request) == 8);
 
 /* Used in group stats replies. */
 struct ofp_bucket_counter {
@@ -1996,12 +1996,12 @@
 
     /* Group counter statistics.
-     * The request body is struct ofp_group_stats_request.
+     * The request body is struct ofp_group_multipart_request.
      * The reply is an array of struct ofp_group_stats. */
     OFPMP_GROUP = 6,
